@@ -1,5 +1,5 @@
 /**
- * Copyright (C) 2023-2024 the Eask authors.
+ * Copyright (C) 2023-2026 the Eask authors.
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
 "use strict";
 
 exports.command = ['recipe [destination]'];
-exports.desc = 'Generate recipe file';
+exports.desc = 'Generate the recipe file';
 exports.builder = yargs => yargs
   .positional(
     'destination', {
